[![Build and Test](https://github.com/imranq2/SparkDataFrameComparer/actions/workflows/build_and_test.yml/badge.svg)](https://github.com/imranq2/SparkDataFrameComparer/actions/workflows/build_and_test.yml)

[![Upload Python Package](https://github.com/imranq2/SparkDataFrameComparer/actions/workflows/main.yml/badge.svg)](https://github.com/imranq2/SparkDataFrameComparer/actions/workflows/main.yml)

[![Known Vulnerabilities](https://snyk.io/test/github/imranq2/SparkDataFrameComparer/badge.svg?targetFile=requirements.txt)](https://snyk.io/test/github/imranq2/SparkDataFrameComparer?targetFile=requirements.txt)

# SparkDataFrameComparer
Deep compare of two data frames (recurses down into array and struct columns)
